@@ -27,8 +27,10 @@
 #include "geo_photos.h"
 #include "poi.h"
 #include "wp.h"
+#include "tracks.h"
+
+#define WTFCOUNTER 5
 
-#define WTFCOUNTER 7
 
 static int wtfcounter=0; 
 
@@ -38,7 +40,11 @@ static int friendfinder_timer = 0;
 static int local_x = 0;
 static int local_y = 0;
 
+
+static int drag_started = 0;
+
 static	GdkPixmap *pixmap_photo = NULL;
+static	GdkPixmap *pixmap_photo_big = NULL;
 
 
 
@@ -140,10 +146,9 @@ on_drawingarea1_button_press_event     (GtkWidget       *widget,
 {
 	
 	wtfcounter = 0;
-	if (
-		(event->type==GDK_BUTTON_PRESS ||
-		 event->type==GDK_2BUTTON_PRESS) )
+	if ( event->type==GDK_2BUTTON_PRESS) 
 	{
+		printf("double click\n");
 		
 		
 		
@@ -154,6 +159,7 @@ on_drawingarea1_button_press_event     (GtkWidget       *widget,
 	mouse_y = (int) event->y;
 	local_x = global_x;
 	local_y = global_y;
+
 	
 	
 		
@@ -166,119 +172,164 @@ on_drawingarea1_button_release_event   (GtkWidget       *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
+	
 	printf("*** %s(): \n",__PRETTY_FUNCTION__);
-	
-	
-	if(wtfcounter >= WTFCOUNTER)
-	{
-		printf("* mouse drag +8events\n");
-		int mouse_dx, mouse_dy;
+
+	if ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK) {
+		printf("CONTROL WAS PRESSED\n");
+		GtkWidget *range;
+		int zoom_old;
+		double factor;
+		int width_center, height_center;
+			
+
+			
+		if(global_zoom<17)
+		{	
+			range = lookup_widget(window1, "vscale1");
+			
+			width_center  = map_drawable->allocation.width 	/ 2;
+			height_center = map_drawable->allocation.height / 2;
+			
+			printf("x vorher: %d, %f, %f\n",global_x,event->x,event->y);
+			
+			zoom_old = global_zoom;
 		
-		global_x = local_x;
-		global_y = local_y;
+			global_zoom++;
+			gtk_range_set_value(GTK_RANGE(range), (double) global_zoom);
+			
+			
+			
+			factor = 2;
+			
+			
+			global_x = 2 * global_x + (int)event->x;
+			global_y = 2 * global_y + (int)event->y;
+			
+			
+			repaint_all();
+		}
+	}
+	else {
 		
-		mouse_dx = mouse_x - (int) event->x;
-		mouse_dy = mouse_y - (int) event->y;
+		if ( event->type==GDK_2BUTTON_PRESS) 
+		{	
+			printf("end double click\n");
+		}
 		
-		global_x += mouse_dx;
-		global_y += mouse_dy;
-	
-		gdk_draw_rectangle (
-			pixmap,
-			widget->style->white_gc,
-			TRUE,
-			0, 0,
-			widget->allocation.width+260,
-			widget->allocation.height+260);
+		if(wtfcounter >= WTFCOUNTER)
+		{
+			printf("* mouse drag +8events\n");
+			int mouse_dx, mouse_dy;
+			
+			global_x = local_x;
+			global_y = local_y;
+			
+			mouse_dx = mouse_x - (int) event->x;
+			mouse_dy = mouse_y - (int) event->y;
+			
+			global_x += mouse_dx;
+			global_y += mouse_dy;
+		
+			gdk_draw_rectangle (
+				pixmap,
+				widget->style->white_gc,
+				TRUE,
+				0, 0,
+				widget->allocation.width+260,
+				widget->allocation.height+260);
+						
+			gtk_widget_queue_draw_area (
+				widget, 
+				0,0,widget->allocation.width+260,widget->allocation.height+260);
+			
+		
+			repaint_all();
+			
+		}
+		
+		if (abs(mouse_x - (int) event->x) < 10 && abs(mouse_y - (int) event->y) < 10)
+		{
+			GSList *list;
+			gboolean friend_found = FALSE;
+			gboolean photo_found = FALSE;
+			gboolean poi_found = FALSE;
+			
+			
+			if(global_show_friends)
+			{
+				for(list = friends_list; list != NULL && !friend_found; list = list->next)
+				{
+					friend_t *f = list->data;
 					
-		gtk_widget_queue_draw_area (
-			widget, 
-			0,0,widget->allocation.width+260,widget->allocation.height+260);
-		
+					if( 	abs(f->screen_x - mouse_x) < 15 &&
+						abs(f->screen_y - mouse_y) < 15)
+					{
+						
+						friend_found = TRUE;
+					}
+				
+				}
+			}
+			
+			if(global_show_photos && !photo_found)
+			{
+				for(list = photo_list; list != NULL && !photo_found; list = list->next)
+				{
+					photo_t *p = list->data;
+					
+					if( 	abs(p->screen_x - mouse_x) < 15 &&
+						abs(p->screen_y - mouse_y) < 15)
+					{
+						
+						photo_found = TRUE;
+					}
+				
+				}
+			}
+			
+			if (global_show_pois )
+			{	
+				for(list = poi_list; list != NULL && !poi_found; list = list->next)
+				{
+					poi_t *p = list->data;
+					
+					if( 	abs(p->screen_x - mouse_x) < 15 &&
+						abs(p->screen_y - mouse_y) < 15)
+					{
+						
+						poi_found = TRUE;
+					}
+				
+				}
+			}
+			
+			
+			if (!friend_found && !photo_found && !poi_found)
+			{	
+	
+				gtk_widget_show(menu1);
+				
+				gtk_menu_popup (GTK_MENU(menu1), NULL, NULL, NULL, NULL, 
+					  event->button, event->time);
+				
+			}
+	
+			if (friend_found)
+				on_item3_activate(NULL, NULL);
+			if (photo_found)
+				on_item10_activate(NULL, NULL);
+			if (poi_found)
+				on_item15_activate(NULL, NULL);
+			
+		}
+	
 		wtfcounter = 0;
 	
-		repaint_all();
-		
+			
+		mouse_dx = mouse_dy = 0;
+		drag_started = 0;
 	}
-	else
-	{
-		GSList *list;
-		gboolean friend_found = FALSE;
-		gboolean photo_found = FALSE;
-		gboolean poi_found = FALSE;
-		
-		
-		if(global_show_friends)
-		{
-			for(list = friends_list; list != NULL && !friend_found; list = list->next)
-			{
-				friend_t *f = list->data;
-				
-				if( 	abs(f->screen_x - mouse_x) < 15 &&
-					abs(f->screen_y - mouse_y) < 15)
-				{
-					
-					friend_found = TRUE;
-				}
-			
-			}
-		}
-		
-		if(global_show_photos && !photo_found)
-		{
-			for(list = photo_list; list != NULL && !photo_found; list = list->next)
-			{
-				photo_t *p = list->data;
-				
-				if( 	abs(p->screen_x - mouse_x) < 15 &&
-					abs(p->screen_y - mouse_y) < 15)
-				{
-					
-					photo_found = TRUE;
-				}
-			
-			}
-		}
-		
-		if (global_show_pois )
-		{	
-			for(list = poi_list; list != NULL && !poi_found; list = list->next)
-			{
-				poi_t *p = list->data;
-				
-				if( 	abs(p->screen_x - mouse_x) < 15 &&
-					abs(p->screen_y - mouse_y) < 15)
-				{
-					
-					poi_found = TRUE;
-				}
-			
-			}
-		}
-		
-		
-		if (!friend_found && !photo_found && !poi_found)
-		{	
-
-			gtk_widget_show(menu1);
-			
-			gtk_menu_popup (GTK_MENU(menu1), NULL, NULL, NULL, NULL, 
-				  event->button, event->time);
-			
-		}
-
-		if (friend_found)
-			on_item3_activate(NULL, NULL);
-		if (photo_found)
-			on_item10_activate(NULL, NULL);
-		if (poi_found)
-			on_item15_activate(NULL, NULL);
-		
-		wtfcounter = 0;
-	}
-
-		
-	mouse_dx = mouse_dy = 0;
 	return FALSE;
 }
 
@@ -306,38 +357,47 @@ on_drawingarea1_motion_notify_event    (GtkWidget       *widget,
 			state = event->state;
 		}
 	 
-		if (state & GDK_BUTTON1_MASK  && wtfcounter>=WTFCOUNTER) {
-		
-		global_autocenter = FALSE;
-			
-		mouse_dx = x - mouse_x;	
-		mouse_dy = y - mouse_y;
-			
-		gdk_draw_drawable (
-			widget->window,
-			widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
-			pixmap,
-			0,0,
-			mouse_dx,mouse_dy,
-			-1,-1);
+		if (state & GDK_BUTTON1_MASK  && wtfcounter>=WTFCOUNTER) 
+		{
+			if(!drag_started)
+			{
+				mouse_x = (int) event->x;
+				mouse_y = (int) event->y;
+				local_x = global_x;
+				local_y = global_y;
 
-		if(mouse_dx>0)
-			gdk_draw_rectangle (
+				drag_started = 1;				
+			}
+			global_autocenter = FALSE;
+				
+			mouse_dx = x - mouse_x;	
+			mouse_dy = y - mouse_y;
+				
+			gdk_draw_drawable (
 				widget->window,
-				widget->style->white_gc,
-				TRUE,
-				0, 0,
-				mouse_dx,
-				widget->allocation.height);
-		
-		if (mouse_dy>0)
-			gdk_draw_rectangle (
-				widget->window,
-				widget->style->white_gc,
-				TRUE,
-				0, 0,
-				widget->allocation.width,
-				mouse_dy);
+				widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+				pixmap,
+				0,0,
+				mouse_dx,mouse_dy,
+				-1,-1);
+	
+			if(mouse_dx>0)
+				gdk_draw_rectangle (
+					widget->window,
+					widget->style->white_gc,
+					TRUE,
+					0, 0,
+					mouse_dx,
+					widget->allocation.height);
+			
+			if (mouse_dy>0)
+				gdk_draw_rectangle (
+					widget->window,
+					widget->style->white_gc,
+					TRUE,
+					0, 0,
+					widget->allocation.width,
+					mouse_dy);
 					
 
 
@@ -552,15 +612,16 @@ on_button3_clicked                     (GtkButton       *button,
 {
 	global_autocenter = TRUE;
 	
-	if(gpsdata)
-	{
-		
-		if(isnan(gpsdata->fix.latitude)==0 && isnan(gpsdata->fix.longitude)==0)
+	if(gpsdata) {
+		if(isnan(gpsdata->fix.latitude) == 0	&&
+		   isnan(gpsdata->fix.longitude)== 0	&&
+		   gpsdata->fix.latitude !=0		&&
+		   gpsdata->fix.longitude!=0) {
 			set_mapcenter(gpsdata->fix.latitude, gpsdata->fix.longitude, global_zoom);
+		}
 	}
 	else
-		printf("***************************\n");
-	printf("++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++");
+		printf("Not autocentering map due to missing gps data\n");
 }
 
 gboolean
@@ -746,7 +807,9 @@ on_combobox1_changed                   (GtkComboBox     *combobox,
 					error);
 	
 	
-	repoconfig__populate_dialog();
+	repaint_all();
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(lookup_widget(window1,"notebook1")), 0);
+
 }
 
 void
@@ -806,55 +869,48 @@ void
 on_okbutton1_clicked                   (GtkButton       *button,
                                         gpointer         user_data)
 {
-	GtkWidget	*entry;
+	GtkWidget	*entry_repo;
 	GtkWidget	*combobox;
 	GtkWidget	*entry_uri;
 	GtkWidget	*entry_dir;
 	GtkWidget	*togglebutton;
-	GtkWidget	*button6;
-	const gchar	*reponame;
+	const gchar	*reponame, *uri, *dir;
+	gboolean	reversed;
 	repo_t *repo = g_new0(repo_t, 1);
 	
-	gtk_widget_hide(dialog1);
 	
-	entry = lookup_widget(dialog1, "entry5");
-	entry_uri = lookup_widget(window1, "entry1");
-	entry_dir = lookup_widget(window1, "entry2");
-	togglebutton = lookup_widget(window1, "checkbutton1");
+	entry_repo = lookup_widget(dialog1, "entry5");
+	entry_uri = lookup_widget(dialog1, "entry20");
+	entry_dir = lookup_widget(dialog1, "entry21");
+	togglebutton = lookup_widget(dialog1, "checkbutton12");
 	combobox = lookup_widget(window1, "combobox1");
-	button6 = lookup_widget(window1, "button6");
 
-	reponame = gtk_entry_get_text(GTK_ENTRY(entry));
+	reponame = gtk_entry_get_text(GTK_ENTRY(entry_repo));
+	uri = gtk_entry_get_text(GTK_ENTRY(entry_uri));
+	dir = gtk_entry_get_text(GTK_ENTRY(entry_dir));
+	reversed = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX(combobox), g_strdup(reponame));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), global_repo_cnt);
 	global_repo_cnt++;
 	
 
-
 	repo->name = g_strdup(reponame);
-	
-	
-	repo->inverted_zoom = FALSE;
+	repo->dir = g_strdup(dir);
+	repo->uri = g_strdup(uri);
+	repo->inverted_zoom = reversed;
 	
 	global_repo_list = g_slist_prepend(global_repo_list, repo);
 	global_curr_repo = global_repo_list;
 	
-	gtk_entry_set_text(GTK_ENTRY(entry_uri), "");
-	gtk_entry_set_text(GTK_ENTRY(entry_dir), "");
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(togglebutton), FALSE);
+	gconf_set_repolist();
+
+	gtk_widget_destroy(dialog1);
 
 	
 	
 	printf("*** %s(): new repo: %s\n",__PRETTY_FUNCTION__, reponame);
-	gtk_entry_set_text(GTK_ENTRY(entry),"");
 	
-	gtk_widget_set_sensitive (button6, TRUE);
-
-
-	
-
-
-
 
 
 }
@@ -864,7 +920,8 @@ void
 on_button7_clicked                     (GtkButton       *button,
                                         gpointer         user_data)
 {
-	
+	dialog1 = create_dialog1();
+
 	gtk_widget_show(dialog1);
 	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 }
@@ -1194,15 +1251,38 @@ on_item4_activate                      (GtkMenuItem     *menuitem,
 {
 	GtkWidget *label;
 	gchar buffer[512];
+	gchar latlon[64];
 	float lat, lon,lat_deg,lon_deg;
 	float distance=0;
-
-	printf("screen x,y: %d %d \n",mouse_x, mouse_y);
+	double unit_conv = 1;
+	static gchar distunit[3];
+	
+	printf("screen x,y, global x,y: %d %d %d %d\n",mouse_x, mouse_y, global_x, global_y);
 	lat = pixel2lat(global_zoom, global_y+mouse_y);
 	lon = pixel2lon(global_zoom, global_x+mouse_x);
 	
+
 	lat_deg = rad2deg(lat);
 	lon_deg = rad2deg(lon);
+	
+	switch (global_latlon_unit)
+	{
+		case 0:
+			g_sprintf(latlon, "%f - %f", lat_deg, lon_deg);
+			break;
+		case 1:
+			g_sprintf(latlon, "%s   %s", 
+				  latdeg2latmin(lat_deg),
+				  londeg2lonmin(lon_deg));
+			break;
+		case 2:
+			g_sprintf(latlon, "%s   %s", 
+				  latdeg2latsec(lat_deg),
+				  londeg2lonsec(lon_deg));
+	}
+
+	
+
 	printf ("##### Lonitude: %f %f - %f %f \n", lat, lon, lat_deg, lon_deg);
 	
 	
@@ -1229,17 +1309,34 @@ on_item4_activate                      (GtkMenuItem     *menuitem,
 	}
 	
 	
+	if(global_speed_unit==1)
+	{
+		unit_conv = 1.0/1.609344;
+		g_sprintf(distunit, "%s", "m");
+	}
+	else if(global_speed_unit==2)
+	{
+		unit_conv = 1.0/1.852;
+		g_sprintf(distunit, "%s", "NM");
+	}
+	else
+	{
+		g_sprintf(distunit, "%s", "km");
+	}
+	
+	
+	
 	label = lookup_widget(window2,"label64");
 	
-	g_sprintf(buffer,"This point: \n"
-			"%f %f \n\n"
-			"Distance from your location: %.2fkm",lat_deg,lon_deg,distance);
+	g_sprintf(buffer,"<b>This point:</b> \n"
+			"%s \n\n"
+			"<b>Distance from your location:</b>\n%.2f%s", latlon, distance*unit_conv, distunit);
 	
-
-	
-	gtk_label_set_text(GTK_LABEL(label),buffer);
-
 	gtk_widget_show (window2);
+
+	
+	gtk_label_set_label(GTK_LABEL(label),buffer);
+
 	
 	
 	
@@ -1367,10 +1464,11 @@ on_drawinarea1_scroll_event            (GtkWidget       *widget,
 		int zoom_old;
 		double factor;
 		int width_center, height_center;
+		static int slowpad = 0;
 		
-		if (event->direction == GDK_SCROLL_UP)
+		if (event->direction == GDK_SCROLL_UP && slowpad % 1 ==0)
 		{
-
+			slowpad++;
 			
 		
 			printf("SCROLL UP\n");
@@ -1402,8 +1500,9 @@ on_drawinarea1_scroll_event            (GtkWidget       *widget,
 				repaint_all();
 			}
 		}
-		else
+		else if (event->direction == GDK_SCROLL_DOWN && slowpad % 1 ==0)
 		{
+			slowpad++;
 			printf("SCROLL DOWN\n");
 			
 			if(global_zoom>2)
@@ -1434,6 +1533,8 @@ on_drawinarea1_scroll_event            (GtkWidget       *widget,
 			}
 
 		}
+		else slowpad++;
+			
 		return TRUE;
 	}
 
@@ -1543,11 +1644,19 @@ on_button18_clicked                    (GtkButton       *button,
 	{
 		gtk_button_set_label(button, "            Stop              ");
 		track_log_open();
+		gconf_client_set_bool(
+				global_gconfclient, 
+				GCONF"/tracklog_on",
+				TRUE, NULL);
 	}
 	else
 	{
 		gtk_button_set_label(button, "            Start             ");
 		track_log_close();
+		gconf_client_set_bool(
+				global_gconfclient, 
+				GCONF"/tracklog_on",
+				FALSE, NULL);
 	}
 }
 
@@ -1745,12 +1854,6 @@ on_drawingarea2_expose_event           (GtkWidget       *widget,
 	return FALSE;
 }
 
-void
-on_closebutton2_clicked                (GtkButton       *button,
-                                        gpointer         user_data)
-{
-
-}
 
 
 void
@@ -1759,9 +1862,12 @@ on_item10_activate                     (GtkMenuItem     *menuitem,
 {
 	GtkWidget *label, *widget;
 	GtkWidget *drawingarea2;
+	
+	static gulong hd1 = 0, hd2 = 0;
 
 	GSList *list;
 	gchar buffer[512];
+	gchar *photo_file = NULL;
 	gboolean photo_found = FALSE;
 
 	GdkPixbuf *photo = NULL;
@@ -1809,7 +1915,7 @@ on_item10_activate                     (GtkMenuItem     *menuitem,
 			
 			
 			photo = gdk_pixbuf_new_from_file_at_size (
-							p->filename, -1,150,
+							p->filename, 240,-1,
 							&error);
 			if(!photo)
 			{
@@ -1818,6 +1924,7 @@ on_item10_activate                     (GtkMenuItem     *menuitem,
 			}
 			else
 			{
+				photo_file = p->filename;
 				
 				printf ("+++++++++++++ F*CKING  DRAWINF +++++++++\n");
 
@@ -1867,13 +1974,17 @@ on_item10_activate                     (GtkMenuItem     *menuitem,
 	gtk_label_set_text(GTK_LABEL(label),buffer);
 
 	widget = lookup_widget(window3, "button29");
-	g_signal_connect (	(gpointer) widget, "clicked",
+	if(hd1) g_signal_handler_disconnect(G_OBJECT(widget), hd1);
+	hd1 = g_signal_connect (	(gpointer) widget, "clicked",
 				G_CALLBACK (on_button29_clicked),
 				(gpointer) wp);
 	
-	
-	
-	
+	widget = lookup_widget(window3, "button21");
+	if(hd2) g_signal_handler_disconnect(G_OBJECT(widget), hd2);
+	hd2 = g_signal_connect (	(gpointer) widget, "clicked",
+				G_CALLBACK (on_button21_clicked),
+				(gpointer) g_strdup(photo_file));
+		
 }
 
 
@@ -1888,25 +1999,79 @@ void
 on_button21_clicked                    (GtkButton       *button,
                                         gpointer         user_data)
 {
-	GtkWidget	*widget;
+	GtkWidget *widget;
+	GtkWidget *drawingarea;
+
+	gchar buffer[512];
+	gchar *photo_file = user_data;
+
+	GdkPixbuf *photo = NULL;
+	GError	*error = NULL;
+	GdkGC *gc;
 	
-	widget = lookup_widget(GTK_WIDGET(button), "drawingarea2");
+printf("*** %s(): \n",__PRETTY_FUNCTION__);
+
+	
+	widget = create_win13_biggeo();
+	gtk_widget_show(widget);
+	
+	drawingarea = lookup_widget(widget, "drawingarea3");
+	
+	photo = gdk_pixbuf_new_from_file_at_size (
+							photo_file, 640,-1,
+							&error);
+	if(!photo)
+	{
+		printf ("+++++++++++++ FOTO NOT FOUND: %s +++++++++\n", photo_file);
+		g_sprintf(buffer, "File not found");
+	}
+	else
+	{
+printf("*** %s():22 \n",__PRETTY_FUNCTION__);
+
+		gc = gdk_gc_new(pixmap_photo);
+		
+		gdk_draw_rectangle (
+			pixmap_photo,
+			drawingarea->style->white_gc,
+			TRUE,
+			0, 0,
+			drawingarea->allocation.width,
+			drawingarea->allocation.height);
+		
+		gdk_draw_pixbuf (
+			pixmap_photo,
+			gc,
+			photo,
+			0,0,
+			0, 0,
+			-1,-1,
+			GDK_RGB_DITHER_NONE, 0, 0);
+		
+		gdk_draw_drawable (
+			drawingarea->window,
+			drawingarea->style->fg_gc[GTK_WIDGET_STATE (drawingarea)],
+			pixmap_photo,
+			0,0,
+			0,0,
+			-1,-1);
+
+		gtk_widget_queue_draw_area (
+			drawingarea, 
+			0, 0,
+			80,80);
+
+	}
+
+printf("*** %s(): 33\n",__PRETTY_FUNCTION__);
 
 	
 		
-	gdk_draw_rectangle (
-		pixmap_photo,
-		widget->style->white_gc,
-		TRUE,
-		0, 0,
-		widget->allocation.width,
-		widget->allocation.height);
-					
-	gtk_widget_queue_draw_area (
-		widget, 
-		0,0,widget->allocation.width,widget->allocation.height);
+
 	
-	gtk_widget_hide(window3);
+	
+	gtk_widget_hide(window3);printf("*** %s(): 44\n",__PRETTY_FUNCTION__);
+
 }
 
 gboolean
@@ -1978,7 +2143,7 @@ on_okbutton4_clicked                   (GtkButton       *button,
 	dialog = lookup_widget(GTK_WIDGET(button), "window6");
 	set_poi(dialog);
 	
-	get_pois();
+
 	global_show_pois = TRUE; 
 	repaint_all();
 }
@@ -2024,7 +2189,7 @@ on_okbutton5_clicked                   (GtkButton       *button,
 
 	gtk_widget_destroy(dialog);
 
-	get_pois();
+
 	
 	widget = lookup_widget(menu1, "item20");
 	pois_shown = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget));
@@ -2547,8 +2712,8 @@ on_item20_activate                     (GtkMenuItem     *menuitem,
 	
 	active = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem));
 	global_show_pois = (active) ? TRUE : FALSE;
-	if(active && poi_list == NULL)
-		get_pois();
+
+
 	
 	repaint_all();
 }
@@ -2577,6 +2742,7 @@ repaint_all()
 {
 	fill_tiles_pixel(global_x, global_y, global_zoom);
 	print_track();
+	paint_loaded_track();
 	paint_friends();
 	paint_photos();
 	paint_pois();
@@ -2695,7 +2861,7 @@ on_okbutton5a_clicked                   (GtkButton       *button,
 	update_poi(widget);
 	
 	
-	get_pois();
+
 	
 	repaint_all();
 }
@@ -2730,12 +2896,16 @@ on_drawingarea1_key_press_event        (GtkWidget       *widget,
                                         GdkEventKey     *event,
                                         gpointer         user_data)
 {
-	if (event->keyval == GDK_Page_Up || event->keyval == GDK_KP_Up)
+	if (event->keyval == GDK_Page_Up || event->keyval == GDK_KP_Up || event->keyval == 'i')
 	{
 		printf("up/dn key pressed\n");	
 		on_button4_clicked(NULL, NULL);
 	}
-	else if(event->keyval == GDK_Page_Down)
+	else if ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK && event->keyval == 'p')
+		geo_photos_open_dialog_photo_correlate();
+	else if ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK && event->keyval == 't')
+		tracks_open_tracks_dialog();
+	else if(event->keyval == GDK_Page_Down || event->keyval == 'o')
 		on_button5_clicked(NULL, NULL);
 	else if(event->keyval == GDK_space)
 		on_button1_clicked(GTK_BUTTON(window1), NULL);
@@ -2919,3 +3089,622 @@ on_entry4_changed                      (GtkEditable     *editable,
 					entry,
 					NULL);
 }
+
+void
+on_button36_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	tracks_open_tracks_dialog();
+}
+
+gboolean
+on_window12_delete_event               (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+	GtkWidget *window;
+	printf("*** %s(): \n",__PRETTY_FUNCTION__);
+
+	window = lookup_widget(widget, "window12");
+	gtk_widget_destroy(window);
+	
+	return FALSE;
+}
+
+void
+on_button37_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget;
+	printf("*** %s(): \n",__PRETTY_FUNCTION__);
+
+	widget = lookup_widget(GTK_WIDGET(button), "window12");
+	gtk_widget_destroy(widget);
+}
+
+void
+on_button38_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget	*entry_repo;
+	GtkWidget	*entry_uri;
+	GtkWidget	*entry_dir;
+	GtkWidget	*togglebutton;
+	repo_t		*repo;
+		
+	dialog8 = create_dialog8();
+		
+	entry_repo = lookup_widget(dialog8, "entry24");
+	entry_uri = lookup_widget(dialog8, "entry25");
+	entry_dir = lookup_widget(dialog8, "entry26");
+	togglebutton = lookup_widget(dialog8, "checkbutton13");
+
+	repo = global_curr_repo->data;
+	gtk_entry_set_text( GTK_ENTRY(entry_repo), repo->name );
+	gtk_entry_set_text( GTK_ENTRY(entry_uri), repo->uri );
+	gtk_entry_set_text( GTK_ENTRY(entry_dir), repo->dir );
+	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(togglebutton), repo->inverted_zoom);
+
+
+	
+	gtk_widget_show(dialog8);
+}
+
+
+void
+on_cancelbutton7_clicked               (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+
+	widget = lookup_widget(GTK_WIDGET(button), "dialog8");
+	
+	gtk_widget_destroy(dialog8);
+}
+
+
+void
+on_okbutton7_clicked                   (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget	*entry_repo;
+	GtkComboBox	*combobox;
+	GtkWidget	*entry_uri;
+	GtkWidget	*entry_dir;
+	GtkWidget	*togglebutton;
+	const gchar	*reponame, *uri, *dir;
+	gboolean	reversed;
+	repo_t 		*repo;
+	
+	repo = global_curr_repo->data;
+	
+	entry_repo = lookup_widget(dialog8, "entry24");
+	entry_uri = lookup_widget(dialog8, "entry25");
+	entry_dir = lookup_widget(dialog8, "entry26");
+	togglebutton = lookup_widget(dialog8, "checkbutton13");
+	combobox = GTK_COMBO_BOX(lookup_widget(window1, "combobox1"));
+
+	reponame = gtk_entry_get_text(GTK_ENTRY(entry_repo));
+	uri = gtk_entry_get_text(GTK_ENTRY(entry_uri));
+	dir = gtk_entry_get_text(GTK_ENTRY(entry_dir));
+	reversed = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
+	
+	repo->name = g_strdup(reponame);
+	repo->dir = g_strdup(dir);
+	repo->uri = g_strdup(uri);
+	repo->inverted_zoom = reversed;
+	
+	global_curr_reponame = g_strdup(reponame);
+	
+	gtk_combo_box_remove_text(combobox, gtk_combo_box_get_active(combobox));
+	gtk_combo_box_prepend_text (combobox, g_strdup(repo->name));
+	gtk_combo_box_set_active(combobox, 0);
+
+	printf("*** %s(): new repo: %s %s\n",__PRETTY_FUNCTION__, repo->name, global_curr_reponame);
+	gconf_set_repolist();
+
+	gtk_widget_destroy(dialog8);
+
+}
+
+void
+on_entry5_changed                      (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+	const char	*txt1, *txt2, *txt3;
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "entry5");
+	txt1 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry20");
+	txt2 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry21");
+	txt3 = gtk_entry_get_text(GTK_ENTRY(widget));
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "okbutton1");
+	
+	if(strlen(txt1) && strlen(txt2) && strlen(txt3))
+		gtk_widget_set_sensitive (widget, TRUE);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
+	
+}
+
+
+void
+on_entry20_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+	const char	*txt1, *txt2, *txt3;
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "entry5");
+	txt1 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry20");
+	txt2 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry21");
+	txt3 = gtk_entry_get_text(GTK_ENTRY(widget));
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "okbutton1");
+	
+	if(strlen(txt1) && strlen(txt2) && strlen(txt3))
+		gtk_widget_set_sensitive (widget, TRUE);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
+	
+}
+
+
+void
+on_entry21_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+	const char	*txt1, *txt2, *txt3;
+	const gchar	*dir;
+
+	int result;
+	
+	dir = gtk_entry_get_text(GTK_ENTRY(editable));
+
+	result = strncmp(dir, "~", 1);
+	if(!result)
+		gtk_entry_set_text(GTK_ENTRY(editable), g_strdup(getenv("HOME")));
+
+
+
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "entry5");
+	txt1 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry20");
+	txt2 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry21");
+	txt3 = gtk_entry_get_text(GTK_ENTRY(widget));
+
+	printf("strlen: %d \n", strlen(txt1));
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "okbutton1");
+	
+	if(strlen(txt1) && strlen(txt2) && strlen(txt3))
+		gtk_widget_set_sensitive (widget, TRUE);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
+	
+	printf("*** %s(): \n",__PRETTY_FUNCTION__);
+}
+
+
+void
+on_checkbutton12_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_entry24_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+	const char	*txt1, *txt2, *txt3;
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "entry24");
+	txt1 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry25");
+	txt2 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry26");
+	txt3 = gtk_entry_get_text(GTK_ENTRY(widget));
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "okbutton7");
+	
+	if(strlen(txt1) && strlen(txt2) && strlen(txt3))
+		gtk_widget_set_sensitive (widget, TRUE);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
+	
+}
+
+
+void
+on_entry25_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+	const char	*txt1, *txt2, *txt3;
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "entry24");
+	txt1 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry25");
+	txt2 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry26");
+	txt3 = gtk_entry_get_text(GTK_ENTRY(widget));
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "okbutton7");
+	
+	if(strlen(txt1) && strlen(txt2) && strlen(txt3))
+		gtk_widget_set_sensitive (widget, TRUE);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
+	
+}
+
+
+void
+on_entry26_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	GtkWidget	*widget;
+	const char	*txt1, *txt2, *txt3;
+	const gchar	*dir;
+	int result;
+	
+	dir = gtk_entry_get_text(GTK_ENTRY(editable));
+
+	result = strncmp(dir, "~", 1);
+	if(!result)
+		gtk_entry_set_text(GTK_ENTRY(editable), g_strdup(getenv("HOME")));
+
+
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "entry24");
+	txt1 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry25");
+	txt2 = gtk_entry_get_text(GTK_ENTRY(widget));
+	widget = lookup_widget(GTK_WIDGET(editable), "entry26");
+	txt3 = gtk_entry_get_text(GTK_ENTRY(widget));
+
+	printf("strlen: %d \n", strlen(txt1));
+	
+	widget = lookup_widget(GTK_WIDGET(editable), "okbutton7");
+	
+	if(strlen(txt1) && strlen(txt2) && strlen(txt3))
+		gtk_widget_set_sensitive (widget, TRUE);
+	else
+		gtk_widget_set_sensitive (widget, FALSE);
+	
+}
+
+
+void
+on_checkbutton13_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+
+}
+
+void
+on_entry21_activate                    (GtkEntry        *entry,
+                                        gpointer         user_data)
+{
+	printf("%s(): \n",__PRETTY_FUNCTION__);
+}
+
+gboolean
+on_eventbox1_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+	printf("%s(): \n",__PRETTY_FUNCTION__);
+	
+	GtkWidget	*window;
+	
+	window = lookup_widget(widget, "drawingarea2");
+
+	
+		
+	gdk_draw_rectangle (
+		pixmap_photo,
+		widget->style->white_gc,
+		TRUE,
+		0, 0,
+		widget->allocation.width,
+		widget->allocation.height);
+					
+	gtk_widget_queue_draw_area (
+		widget, 
+		0,0,widget->allocation.width,widget->allocation.height);
+	
+	gtk_widget_hide(window3);
+	
+	return FALSE;
+}
+
+gboolean
+on_eventbox2_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+	GtkWidget *window;
+	
+	window = lookup_widget(widget, "win13_biggeo");
+	
+	gtk_widget_hide(window);
+	
+  return FALSE;
+}
+
+gboolean
+on_drawingarea3_configure_event        (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data)
+{
+	printf("*** %s(): \n",__PRETTY_FUNCTION__);
+	
+
+	
+	if (!pixmap_photo_big)
+	pixmap_photo = gdk_pixmap_new (
+			widget->window,
+			widget->allocation.width,
+			widget->allocation.height,
+			-1);
+
+	if(pixmap_photo_big)
+		printf("pixmap_photo NOT NULL");
+	else
+		printf("aieee: pixmap_photo NULL\n");
+
+	
+	
+	
+	
+	
+	
+	return FALSE;
+}
+
+
+gboolean
+on_drawingarea3_expose_event           (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data)
+{
+	printf("** D2: expose event\n");
+	
+	gdk_draw_drawable (
+		widget->window,
+		widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+		pixmap_photo,
+		event->area.x, event->area.y,
+		event->area.x, event->area.y,
+		event->area.width, event->area.height);
+	
+	
+	return FALSE;
+}
+
+void
+on_itemgeocode1_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+	geo_photos_open_dialog_photo_correlate();
+}
+
+
+void
+on_itemimport1_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_itemselect1_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_button39_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	geo_photos_geocode_track_select_dialog(button, user_data);
+}
+
+
+void
+on_button40_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	geo_photos_geocode_dir_select_dialog(button, user_data);
+}
+
+
+void
+on_button41_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+
+}
+
+
+void
+on_cancelbutton8_clicked               (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	geo_photo_cancel_dialog_photo_correlate();
+}
+
+
+void
+on_okbutton8_clicked                   (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	geo_photo_close_dialog_photo_correlate();
+}
+
+void
+on_button44_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	geo_photos_open_dialog_image_data();
+}
+
+
+void
+on_button45_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget = lookup_widget(GTK_WIDGET(button), "dialog_image_data");
+	geo_photo_dialog_image_data_next(widget, user_data, GEOPHOTO_PREV);
+}
+
+
+void
+on_button46_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget = lookup_widget(GTK_WIDGET(button), "dialog_image_data");
+	geo_photo_dialog_image_data_next(widget, user_data, GEOPHOTO_NEXT);
+}
+
+void
+on_button47_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget = lookup_widget(GTK_WIDGET(button), "dialog_image_data");
+	geo_photo_dialog_image_data_next(widget, user_data, GEOPHOTO_FIRST);
+}
+
+
+void
+on_button48_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget = lookup_widget(GTK_WIDGET(button), "dialog_image_data");
+	geo_photo_dialog_image_data_next(widget, user_data, GEOPHOTO_LAST);
+}
+
+void
+on_okbutton9_clicked                   (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	printf("%s \n", __PRETTY_FUNCTION__);
+	geo_photo_close_dialog_image_data();
+}
+
+
+void
+on_button49_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	geo_photo_cancel_dialog_image_data();
+}
+
+
+gboolean
+on_eventbox3_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+	
+	
+	return FALSE;
+}
+
+void
+on_checkbutton14_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+	geo_photo_set_add_to_database(togglebutton);
+}
+
+
+void
+on_combobox7_changed                   (GtkComboBox     *combobox,
+                                        gpointer         user_data)
+{
+	geo_photo_set_timezone(combobox);
+}
+
+
+gboolean
+on_dialog_geocode_delete_event         (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+	geo_photo_cancel_dialog_photo_correlate();
+	return TRUE;
+}
+
+
+gboolean
+on_dialog_image_data_delete_event      (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data)
+{
+printf("I am deleted\n");
+	geo_photo_close_dialog_image_data();
+
+  return TRUE;
+}
+
+gboolean
+on_eventbox4_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+	GtkWidget *window;
+	window = lookup_widget(widget, "window2");
+	gtk_widget_hide(window);
+	
+	return FALSE;
+}
+
+void
+on_entry28_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data)
+{
+	geo_photo_correction_entry_cb(editable);
+}
+
+
+void
+on_button50_clicked                    (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *window = lookup_widget(GTK_WIDGET(button), "dialog_image_data");
+	geo_photo_dialog_image_data_next(window, user_data, GEOPHOTO_FULLSIZE);	
+	gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
+}
+
+void
+on_closebutton2_clicked                (GtkButton       *button,
+                                        gpointer         user_data)
+{
+	GtkWidget *widget = lookup_widget(GTK_WIDGET(button), "dialog_geocode_result");	
+	gtk_widget_hide(widget);
+}
