@@ -548,3 +548,194 @@ on_entry3_changed                      (GtkEditable     *editable,
 void
 on_entry4_changed                      (GtkEditable     *editable,
                                         gpointer         user_data);
+
+void
+on_button36_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_window12_delete_event               (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_button37_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button38_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cancelbutton7_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_okbutton7_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_entry5_changed                      (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_entry20_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_entry21_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_checkbutton12_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_entry24_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_entry25_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_entry26_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_checkbutton13_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_entry21_activate                    (GtkEntry        *entry,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox1_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox1_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox1_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox2_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea3_configure_event        (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea3_expose_event           (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data);
+
+void
+on_itemgeocode1_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_itemimport1_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_itemselect1_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_button39_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button40_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button41_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_cancelbutton8_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_okbutton8_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button44_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button45_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button46_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button47_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button48_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_okbutton9_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button49_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox3_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_checkbutton14_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_combobox7_changed                   (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog_geocode_delete_event         (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog_image_data_delete_event      (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+gboolean
+on_eventbox4_button_release_event      (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_entry28_changed                     (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_button50_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_closebutton2_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
