@@ -43,7 +43,7 @@ track_log()
 	{
 		
 		time_sec = (time_t)gpsdata->fix.time;
-		ts = gmtime(&time_sec);
+		ts = localtime(&time_sec);
 		
 		
 		strftime(buffer, sizeof(buffer), "%Y-%m-%dT%H:%M:%SZ", ts);
@@ -358,6 +358,7 @@ cb_gps_timer()
 				if(isnan(trip_delta))
 				{
 					
+					
 					printf("WTF??? %f %f %f %f %f \n",lat,lon,lat_tmp,lon_tmp,trip_delta);
 				}
 				else
@@ -476,7 +477,10 @@ gconf_get_repolist()
 		repo_t *repo1 = g_new0(repo_t, 1);
 		repo_t *repo2 = g_new0(repo_t, 1);
 		repo_t *repo3 = g_new0(repo_t, 1);
+		repo_t *repo4 = g_new0(repo_t, 1);
+		repo_t *repo5 = g_new0(repo_t, 1);
 
+		
 		printf("REPOLIST == NULL\n");
 		repo1->name = g_strdup("OSM");
 		repo1->uri  = g_strdup("http://tile.openstreetmap.org/%d/%d/%d.png");
@@ -495,6 +499,19 @@ gconf_get_repolist()
 		repo3->dir  = g_strdup_printf("%s/Maps/openaerial",global_home_dir);
 		repo3->inverted_zoom = 0;
 		global_repo_list = g_slist_append(global_repo_list, repo3);
+		
+		repo4->name = g_strdup("Opencyclemap");
+		repo4->uri  = g_strdup("http://a.andy.sandbox.cloudmade.com/tiles/cycle/%d/%d/%d.png");
+		repo4->dir  = g_strdup_printf("%s/Maps/opencyclemap",global_home_dir);
+		repo4->inverted_zoom = 0;
+		global_repo_list = g_slist_append(global_repo_list, repo4);
+		
+		repo5->name = g_strdup("Google Sat (testing only)");
+		repo5->uri  = g_strdup("http://khm1.google.com/kh?v=34&hl=en&x=%d&s=&y=%d&z=%d");
+		repo5->dir  = g_strdup_printf("%s/Maps/googlesat",global_home_dir);
+		repo5->inverted_zoom = 1;
+		global_repo_list = g_slist_append(global_repo_list, repo5);
+		
 	}
 	
 	
@@ -567,20 +584,7 @@ gconf_set_repolist()
 void
 repoconfig__populate_dialog()
 {
-	GtkWidget	*entry_uri;
-	GtkWidget	*entry_dir;
-	GtkWidget	*togglebutton;
-	repo_t		*repo;
-	
-	entry_uri = lookup_widget(window1, "entry1");
-	entry_dir = lookup_widget(window1, "entry2");
-	togglebutton = lookup_widget(window1, "checkbutton1");
-	
-	
-	repo = global_curr_repo->data;
-	gtk_entry_set_text( GTK_ENTRY(entry_uri), repo->uri );
-	gtk_entry_set_text( GTK_ENTRY(entry_dir), repo->dir );
-	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(togglebutton), repo->inverted_zoom);
+
 }
 
 void
@@ -718,7 +722,15 @@ init()
 	gchar buffer[128];
 	gboolean gconf_fftimer_running;
 	char *str = NULL;
-
+	int screen_height;
+	
+	screen_height = gdk_screen_get_height(gdk_screen_get_default());
+	
+	if(screen_height < 640)
+	{
+		printf("height: %d \n",screen_height);
+		gtk_window_resize(GTK_WINDOW(window1), 480, screen_height-10);
+	}
 	
 	tangogps_dir = g_strconcat(global_home_dir, "/.tangogps", NULL);
 	g_mkdir(tangogps_dir, 0700);
@@ -908,6 +920,9 @@ init()
 	gtk_entry_set_text(GTK_ENTRY(widget), g_strdup(str));
 	g_free(str);
 	
+	if (gconf_client_get_bool(global_gconfclient, GCONF"/tracklog_on", NULL))
+		gtk_button_clicked(GTK_BUTTON(lookup_widget(window1,"button18")));
+	
 	timer = g_timeout_add (1000,cb_gps_timer,data);
 	
 	gtk_window_set_icon_from_file(GTK_WINDOW(window1), PACKAGE_PIXMAPS_DIR "/" PNAME ".png" ,&err);
