@@ -7,6 +7,7 @@
 #endif
  
 #include <locale.h>
+#include <string.h>
 #include <gtk/gtk.h>
 
 #include "interface.h"
@@ -25,6 +26,7 @@ main (int argc, char *argv[])
   textdomain (GETTEXT_PACKAGE);
 #endif
 
+
   gtk_set_locale ();
 	
   if (!g_thread_supported ()) g_thread_init (NULL);
@@ -47,8 +49,10 @@ main (int argc, char *argv[])
   window1 = create_window1 ();
   gtk_widget_show (window1);
 
+  if(argc > 1 && strcmp(argv[1], "-fullscreen") == 0)
+	  on_button1_clicked(GTK_BUTTON(window1), NULL);
+  
   window2 = create_window2();
-  dialog1 = create_dialog1();
   window3 = create_window3();
   menu1 = create_menu1();
 
