@@ -11,6 +11,7 @@
 #include "converter.h"
 #include "interface.h"
 #include "util.h"
+#include "tile_management.h"
 
 #include <glib.h>
 #include <glib/gprintf.h>
@@ -46,6 +47,7 @@ static gboolean new_dialog = TRUE;
 		creator TEXT, bookmarked REAL, user_rating REAL, rating REAL, user_comment TEXT);"
 
 
+
 double
 parse_degrees(const char *s)
 {
@@ -134,6 +136,8 @@ paint_pois()
 
 	if(global_show_pois)
 	{
+		get_pois();
+		
 		for(list = poi_list; list != NULL; list = list->next)
 		{
 			poi_t *p = list->data;
@@ -254,7 +258,7 @@ void set_combobox_subcat(GtkWidget *widget, int choice)
 	
 	GtkCellRenderer *renderer;
 	GtkWidget *vbox;
-	char *subcat_lists[14];
+	char *subcat_lists[15];
 		printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
 	subcat_lists[0] = "---"; 
@@ -364,7 +368,7 @@ set_poi(GtkWidget *dialog)
 
 	const char *keyword_raw;
 	char *desc, *desc_raw, *keyword;
-	char sql[512];
+	char *sql;
 	char *db;
 	int visibility, price_range = 0, extended_open;
 	int category, subcategory;
@@ -410,7 +414,7 @@ set_poi(GtkWidget *dialog)
 	
 	db = g_strconcat(tangogps_dir, "/", POI_DB, NULL);	
 	
-	g_snprintf(sql, 2048, 	
+	sql = g_strdup_printf( 	
 			"INSERT INTO poi "
 			"(idmd5, lat, lon, visibility, cat, subcat, keywords, desc, price_range, extended_open) "
 			"VALUES ('%.0f%.0f',%f,%f,%d,%d,%d,'%s','%s',%d,%d)",
@@ -430,7 +434,7 @@ printf("size of gdouble: %d",sizeof(double));
 
 	g_free(desc);
 	g_free(desc_raw);
-	
+	g_free(sql);
 	gtk_widget_destroy(dialog);
 	
 	
@@ -449,7 +453,7 @@ update_poi(GtkWidget *dialog)
 
 	const char *keyword_raw, *idmd5;
 	char *desc, *desc_raw, *keyword;
-	char sql[512];
+	char *sql;
 	char *db;
 
 
@@ -491,7 +495,7 @@ update_poi(GtkWidget *dialog)
 	
 
 
-	g_snprintf(sql, 2048, 	
+	sql = g_strdup_printf( 	
 			"UPDATE "
 				"poi "
 			"SET "
@@ -518,6 +522,7 @@ printf("SQL: %s\n",sql);
 
 	g_free(desc);
 	g_free(desc_raw);
+	g_free(sql);
 	
 	gtk_widget_destroy(dialog);
 	
@@ -553,7 +558,7 @@ printf("SQL: %s\n",sql);
 
 	res = sql_execute(db, sql, NULL);
 	
-	get_pois();
+
 	repaint_all();
 
 	
@@ -569,25 +574,43 @@ get_pois()
 {
 	char sql[256];
 	char *db;
+	bbox_t bbox;
 		
 	printf("*** %s(): \n",__PRETTY_FUNCTION__);
 
+	bbox = get_bbox_deg();
 
 	db = g_strconcat(tangogps_dir, "/", POI_DB, NULL);
 
 	
-	
+	if(poi_list) g_slist_free(poi_list);
 	poi_list = NULL;
 	
 	
 	
 	if(global_poi_cat==0)
 	{
-		g_sprintf(sql, "SELECT * FROM poi LIMIT 30000;");
+		g_snprintf(sql, 256, 
+				"SELECT * FROM poi "
+				"WHERE lat<%f AND lat>%f AND lon>%f AND lon<%f "
+				"LIMIT 1000;",
+				bbox.lat1,bbox.lat2,
+				bbox.lon1, bbox.lon2
+				);
+		printf("%s \n",sql);
 	}
 	else if(global_poi_cat>=1)
 	{
-		g_snprintf(sql, 256, "SELECT * FROM poi WHERE cat=%d LIMIT 1000;",global_poi_cat);
+
+		g_snprintf(sql, 256, 
+				"SELECT * FROM poi "
+				"WHERE  cat=%d AND lat<%f AND lat>%f AND lon>%f AND lon<%f "
+				"LIMIT 1000;",
+				global_poi_cat,
+				bbox.lat1,bbox.lat2,
+				bbox.lon1, bbox.lon2
+				);		
+		
 	}
 	
 
@@ -611,7 +634,7 @@ show_poi_detail()
 	GtkWidget *window, *widget;
 	GtkWidget *label;
 	GSList *list;
-	gchar buffer[512],buffer2[1024];
+	gchar *buffer = NULL, *buffer2 = NULL;
 	gboolean poi_found = FALSE;
 	float lat, lon,lat_deg,lon_deg;
 	float distance=0;
@@ -679,10 +702,10 @@ show_poi_detail()
 				my_strescape_back(p->keywords,NULL));
 	
 			
-			g_sprintf(buffer, 
+			buffer = g_strdup_printf( 
 				"<b>%s</b> ",
 				my_strescape_back(p->keywords,NULL));
-			g_sprintf(buffer2, "%s \n\nDistance: %.3fkm ",
+			buffer2 = g_strdup_printf("%s \n\nDistance: %.3fkm ",
 				my_strescape_back(p->desc,NULL), distance);
 printf("%s %s \n",buffer, buffer2);			
 			poi_found = TRUE;
